pack_bytes_u32words

Function pack_bytes_u32words 

pub fn pack_bytes_u32words(message: &[u8], big_endian: bool) -> Vec<Word>
Pack message bytes into 32-bit words, one word per wire with the high 32 bits zero.

The final word is zero-padded if the message length is not a multiple of 4. big_endian selects the byte order within each word.