resolve_hasher_mode

Function resolve_hasher_mode 

pub fn resolve_hasher_mode(
    params: &HasherParams,
    hasher: &str,
    supports_variable: bool,
) -> Result<HasherMode>
Resolve HasherParams into the gadget shape the circuit should be built from.

supports_variable is false for hashers that only have a fixed-length gadget (Blake2s, Blake2b, Blake3); passing --max-message-len to those is an error.